window.Gleam.initSearch([{"doc":"glint","title":"glint","content":"# glint\n\n[![Hex Package](https://img.shields.io/hexpm/v/glint?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glint)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glint?color=ffaff3)](https://hex.pm/packages/glint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glint/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/glint/main)](https://github.com/tanklesxl/glint/actions)\n\nGleam command line argument parsing with basic flag support.\n\n## Installation\n\nTo install from hex:\n\n```sh\ngleam add glint\n```\n\n## Usage\n\nYou can import `glint` as a dependency and use it as follows:\n(found in `test/mini_demo.gleam`, for a more complete example see `test/demo.gleam`)\n\n```gleam\n  import gleam/io\n  import gleam/result\n  import gleam/string.{join, uppercase}\n  import gleam/function.{compose}\n  import gleam/erlang.{start_arguments}\n  import glint\n  import glint/flag\n\n  const caps = &quot;caps&quot;\n\n  fn hello(input: glint.CommandInput) -&gt; Nil {\n    let assert Ok(caps) = flag.get_bool(from: input.flags, for: caps)\n\n    [&quot;Hello,&quot;, ..input.args]\n    |&gt; case caps {\n      True -&gt; compose(join(_, &quot; &quot;), uppercase)\n      False -&gt; join(_, &quot; &quot;)\n    }\n    |&gt; string.append(&quot;!&quot;)\n    |&gt; io.println\n  }\n\n\n  pub fn main() {\n    let caps_flag =\n      flag.B\n      |&gt; flag.default(False)\n      |&gt; flag.new\n      |&gt; flag.description(&quot;Capitalize the provided name&quot;)\n\n    glint.new()\n    |&gt; glint.add(\n      at: [],\n      do: glint.command(hello)\n      |&gt; glint.flag(caps, caps_flag)\n      |&gt; glint.description(&quot;Prints Hello, &lt;NAME&gt;!&quot;),\n    )\n    |&gt; glint.with_pretty_help(glint.default_pretty_help())\n    |&gt; glint.run(start_arguments())\n  }\n```\n\nRun it with either of:\n\n- `gleam run Bob`, `gleam run -- --caps=false Bob`, or `gleam run Bob --caps=false` which will print `Hello, Bob!`\n- `gleam run -- --caps Bob` or `gleam run -- --caps=true Bob`, or `gleam run Bob --caps` which will print `HELLO, BOB!`\n\n### Built-In Help messages\n\nRun `gleam run -- --help` to print the generated help message, which in this case will look like:\n\n```text\nPrints Hello, &lt;NAME&gt;!\n\nUSAGE:\n        &#39;gleam run &lt;NAME&gt;&#39; or &#39;gleam run &lt;NAME&gt; --caps&#39;\n\nFLAGS:\n        --help                  Print help information\n        --caps=&lt;CAPS&gt;           Capitalize the provided name\n```\n\n_Note_: Due to [this issue](https://github.com/gleam-lang/gleam/issues/1457) commands with flags immediately after `gleam run` must include the `--` as shown above\n","url":"index.html"},{"doc":"glint/flag/constraint","title":"Constraint","content":"pub type Constraint(a) =\n  fn(a) -&gt; Result(Nil)\n Constraint type for verifying flag values\n\n\nSynonyms:\nglint/flag/constraint.Constraint\nglint/flag/constraint Constraint","url":"glint/flag/constraint.html#Constraint"},{"doc":"glint/flag/constraint","title":"each","content":"pub fn each(constraint: fn(a) -&gt; Result(Nil, Snag)) -&gt; fn(List(a)) -&gt;\n  Result(Nil, Snag)\n each is a convenience function for applying a Constraint(a) to a List(a).\n This is useful because the default behaviour for constraints on lists is that they will apply to the list as a whole.\n \n For example, to apply one_of to all items in a `List(Int)`:\n \n [1, 2, 3, 4] |&gt; one_of |&gt; each\n \nSynonyms:\nglint/flag/constraint.each\nglint/flag/constraint each","url":"glint/flag/constraint.html#each"},{"doc":"glint/flag/constraint","title":"none_of","content":"pub fn none_of(disallowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n none_of returns a Constraint that ensures the parsed flag value is not one of the disallowed values.\n\nSynonyms:\nglint/flag/constraint.none_of\nglint/flag/constraint none_of","url":"glint/flag/constraint.html#none_of"},{"doc":"glint/flag/constraint","title":"one_of","content":"pub fn one_of(allowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n one_of returns a Constraint that ensures the parsed flag value is\n one of the allowed values.\n\nSynonyms:\nglint/flag/constraint.one_of\nglint/flag/constraint one_of","url":"glint/flag/constraint.html#one_of"},{"doc":"glint/flag/constraint","title":"glint/flag/constraint","content":"","url":"glint/flag/constraint.html"},{"doc":"glint/flag","title":"Description","content":"pub type Description =\n  String\n Flag descriptions\n\n\nSynonyms:\nglint/flag.Description\nglint/flag Description","url":"glint/flag.html#Description"},{"doc":"glint/flag","title":"Flag","content":"pub type Flag {\n  Flag(value: Value, description: Description)\n}\n Flag data and descriptions\n\nFlag(value: Value, description: Description)\n\n\nSynonyms:\nglint/flag.Flag\nglint/flag Flag","url":"glint/flag.html#Flag"},{"doc":"glint/flag","title":"Internal","content":"pub opaque type Internal(a)\n An internal representation of flag contents\n\n\nSynonyms:\nglint/flag.Internal\nglint/flag Internal","url":"glint/flag.html#Internal"},{"doc":"glint/flag","title":"Map","content":"pub type Map =\n  map.Map(String, Flag)\n Associate flag names to their current values.\n\n\nSynonyms:\nglint/flag.Map\nglint/flag Map","url":"glint/flag.html#Map"},{"doc":"glint/flag","title":"Value","content":"pub type Value {\n  B(Internal(Bool))\n  I(Internal(Int))\n  LI(Internal(List(Int)))\n  F(Internal(Float))\n  LF(Internal(List(Float)))\n  S(Internal(String))\n  LS(Internal(List(String)))\n}\n Supported flag types.\n The constructors of this Value type can also be used as `ValueBuilder`s\n\nB(Internal(Bool))\n Boolean flags, to be passed in as `--flag=true` or `--flag=false`.\n Can be toggled by omitting the desired value like `--flag`.\n Toggling will negate the existing value.\n\n\nI(Internal(Int))\n Int flags, to be passed in as `--flag=1`\n\n\nLI(Internal(List(Int)))\n List(Int) flags, to be passed in as `--flag=1,2,3`\n\n\nF(Internal(Float))\n Float flags, to be passed in as `--flag=1.0`\n\n\nLF(Internal(List(Float)))\n List(Float) flags, to be passed in as `--flag=1.0,2.0`\n\n\nS(Internal(String))\n String flags, to be passed in as `--flag=hello`\n\n\nLS(Internal(List(String)))\n List(String) flags, to be passed in as `--flag=hello,world`\n\n\nSynonyms:\nglint/flag.Value\nglint/flag Value","url":"glint/flag.html#Value"},{"doc":"glint/flag","title":"ValueBuilder","content":"pub type ValueBuilder(a) =\n  fn(Internal(a)) -&gt; Value\n A type that facilitates the usage of builder functions for creating `Value`s\n\n\nSynonyms:\nglint/flag.ValueBuilder\nglint/flag ValueBuilder","url":"glint/flag.html#ValueBuilder"},{"doc":"glint/flag","title":"prefix","content":"pub const prefix: String = &quot;--&quot;\n Flag inputs must start with this prefix\n\nSynonyms:\nglint/flag.prefix\nglint/flag prefix","url":"glint/flag.html#prefix"},{"doc":"glint/flag","title":"build_map","content":"pub fn build_map(flags: List(#(String, Flag))) -&gt; Map(\n  String,\n  Flag,\n)\n Convert a list of flags to a Map.\n\nSynonyms:\nglint/flag.build_map\nglint/flag build_map","url":"glint/flag.html#build_map"},{"doc":"glint/flag","title":"constraint","content":"pub fn constraint(for val: fn(Internal(a)) -&gt; Value, of constraint: fn(\n    a,\n  ) -&gt; Result(Nil, Snag)) -&gt; fn(Internal(a)) -&gt; Value\n attach a constraint to a `Value`\n\nSynonyms:\nglint/flag.constraint\nglint/flag constraint","url":"glint/flag.html#constraint"},{"doc":"glint/flag","title":"default","content":"pub fn default(for val: fn(Internal(a)) -&gt; Value, of default: a) -&gt; fn(\n  Internal(a),\n) -&gt; Value\n Set the default value for a flag `Value`\n\nSynonyms:\nglint/flag.default\nglint/flag default","url":"glint/flag.html#default"},{"doc":"glint/flag","title":"description","content":"pub fn description(for flag: Flag, of description: String) -&gt; Flag\n attach a description to a `Flag`\n\nSynonyms:\nglint/flag.description\nglint/flag description","url":"glint/flag.html#description"},{"doc":"glint/flag","title":"flag_type_help","content":"pub fn flag_type_help(flag: #(String, Flag)) -&gt; String\n Generate the help message contents for a single flag\n \nSynonyms:\nglint/flag.flag_type_help\nglint/flag flag_type_help","url":"glint/flag.html#flag_type_help"},{"doc":"glint/flag","title":"flags_help","content":"pub fn flags_help(flags: Map(String, Flag)) -&gt; List(String)\n Generate help messages for all flags\n\nSynonyms:\nglint/flag.flags_help\nglint/flag flags_help","url":"glint/flag.html#flags_help"},{"doc":"glint/flag","title":"get_bool","content":"pub fn get_bool(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  Bool,\n  Snag,\n)\n Gets the current value for the associated bool flag\n\nSynonyms:\nglint/flag.get_bool\nglint/flag get_bool","url":"glint/flag.html#get_bool"},{"doc":"glint/flag","title":"get_bool_value","content":"pub fn get_bool_value(from flag: #(String, Flag)) -&gt; Result(\n  Bool,\n  Snag,\n)\n Gets the current value for the provided bool flag\n\nSynonyms:\nglint/flag.get_bool_value\nglint/flag get_bool_value","url":"glint/flag.html#get_bool_value"},{"doc":"glint/flag","title":"get_float","content":"pub fn get_float(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  Float,\n  Snag,\n)\n Gets the current value for the associated float flag\n\nSynonyms:\nglint/flag.get_float\nglint/flag get_float","url":"glint/flag.html#get_float"},{"doc":"glint/flag","title":"get_float_value","content":"pub fn get_float_value(from flag: #(String, Flag)) -&gt; Result(\n  Float,\n  Snag,\n)\n Gets the current value for the provided float flag\n\nSynonyms:\nglint/flag.get_float_value\nglint/flag get_float_value","url":"glint/flag.html#get_float_value"},{"doc":"glint/flag","title":"get_floats","content":"pub fn get_floats(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  List(Float),\n  Snag,\n)\n Gets the current value for the associated floats flag\n\nSynonyms:\nglint/flag.get_floats\nglint/flag get_floats","url":"glint/flag.html#get_floats"},{"doc":"glint/flag","title":"get_floats_value","content":"pub fn get_floats_value(from flag: #(String, Flag)) -&gt; Result(\n  List(Float),\n  Snag,\n)\n Gets the current value for the provided floats flag\n\nSynonyms:\nglint/flag.get_floats_value\nglint/flag get_floats_value","url":"glint/flag.html#get_floats_value"},{"doc":"glint/flag","title":"get_int","content":"pub fn get_int(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  Int,\n  Snag,\n)\n Gets the current value for the associated int flag\n\nSynonyms:\nglint/flag.get_int\nglint/flag get_int","url":"glint/flag.html#get_int"},{"doc":"glint/flag","title":"get_int_value","content":"pub fn get_int_value(from flag: #(String, Flag)) -&gt; Result(\n  Int,\n  Snag,\n)\n Gets the current value for the provided int flag\n\nSynonyms:\nglint/flag.get_int_value\nglint/flag get_int_value","url":"glint/flag.html#get_int_value"},{"doc":"glint/flag","title":"get_ints","content":"pub fn get_ints(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  List(Int),\n  Snag,\n)\n Gets the current value for the associated ints flag\n\nSynonyms:\nglint/flag.get_ints\nglint/flag get_ints","url":"glint/flag.html#get_ints"},{"doc":"glint/flag","title":"get_ints_value","content":"pub fn get_ints_value(from flag: #(String, Flag)) -&gt; Result(\n  List(Int),\n  Snag,\n)\n Gets the current value for the provided ints flag\n\nSynonyms:\nglint/flag.get_ints_value\nglint/flag get_ints_value","url":"glint/flag.html#get_ints_value"},{"doc":"glint/flag","title":"get_string","content":"pub fn get_string(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  String,\n  Snag,\n)\n Gets the current value for the associated string flag\n\nSynonyms:\nglint/flag.get_string\nglint/flag get_string","url":"glint/flag.html#get_string"},{"doc":"glint/flag","title":"get_string_value","content":"pub fn get_string_value(from flag: #(String, Flag)) -&gt; Result(\n  String,\n  Snag,\n)\n Gets the current value for the provided string flag\n\nSynonyms:\nglint/flag.get_string_value\nglint/flag get_string_value","url":"glint/flag.html#get_string_value"},{"doc":"glint/flag","title":"get_strings","content":"pub fn get_strings(from flags: Map(String, Flag), for name: String) -&gt; Result(\n  List(String),\n  Snag,\n)\n Gets the current value for the associated strings flag\n\nSynonyms:\nglint/flag.get_strings\nglint/flag get_strings","url":"glint/flag.html#get_strings"},{"doc":"glint/flag","title":"get_strings_value","content":"pub fn get_strings_value(from flag: #(String, Flag)) -&gt; Result(\n  List(String),\n  Snag,\n)\n Gets the current value for the provided strings flag\n\nSynonyms:\nglint/flag.get_strings_value\nglint/flag get_strings_value","url":"glint/flag.html#get_strings_value"},{"doc":"glint/flag","title":"new","content":"pub fn new(of val: fn(Internal(a)) -&gt; Value) -&gt; Flag\n create a new `Flag`\n\nSynonyms:\nglint/flag.new\nglint/flag new","url":"glint/flag.html#new"},{"doc":"glint/flag","title":"update_flags","content":"pub fn update_flags(in flags: Map(String, Flag), with flag_input: String) -&gt; Result(\n  Map(String, Flag),\n  Snag,\n)\n Updates a flag value, ensuring that the new value can satisfy the required type.\n Assumes that all flag inputs passed in start with --\n This function is only intended to be used from glint.execute_root\n\nSynonyms:\nglint/flag.update_flags\nglint/flag update_flags","url":"glint/flag.html#update_flags"},{"doc":"glint/flag","title":"glint/flag","content":"","url":"glint/flag.html"},{"doc":"glint","title":"CmdResult","content":"pub type CmdResult(a) =\n  Result(Out(a))\n Result type for command execution\n\n\nSynonyms:\nglint.CmdResult\nglint CmdResult","url":"glint.html#CmdResult"},{"doc":"glint","title":"Command","content":"pub opaque type Command(a)\n CommandNode contents\n\n\nSynonyms:\nglint.Command\nglint Command","url":"glint.html#Command"},{"doc":"glint","title":"CommandInput","content":"pub type CommandInput {\n  CommandInput(args: List(String), flags: FlagMap)\n}\n Input type for `Runner`.\n\nCommandInput(args: List(String), flags: FlagMap)\n\n\nSynonyms:\nglint.CommandInput\nglint CommandInput","url":"glint.html#CommandInput"},{"doc":"glint","title":"Config","content":"pub type Config(a) {\n  Config(pretty_help: Option(PrettyHelp))\n}\n Config for glint\n\nConfig(pretty_help: Option(PrettyHelp))\n\n\nSynonyms:\nglint.Config\nglint Config","url":"glint.html#Config"},{"doc":"glint","title":"Glint","content":"pub opaque type Glint(a)\n Glint container type for config and commands\n\n\nSynonyms:\nglint.Glint\nglint Glint","url":"glint.html#Glint"},{"doc":"glint","title":"Out","content":"pub type Out(a) {\n  Out(a)\n  Help(String)\n}\n Ok type for command execution \n\nOut(a)\n Container for the command return value\n\nHelp(String)\n Container for the generated help string\n\nSynonyms:\nglint.Out\nglint Out","url":"glint.html#Out"},{"doc":"glint","title":"PrettyHelp","content":"pub type PrettyHelp {\n  PrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n}\n PrettyHelp defines the header colours to be used when styling help text\n\nPrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n\n\nSynonyms:\nglint.PrettyHelp\nglint PrettyHelp","url":"glint.html#PrettyHelp"},{"doc":"glint","title":"Runner","content":"pub type Runner(a) =\n  fn(CommandInput) -&gt; a\n Function type to be run by `glint`.\n\n\nSynonyms:\nglint.Runner\nglint Runner","url":"glint.html#Runner"},{"doc":"glint","title":"Stub","content":"pub type Stub(a) {\n  Stub(\n    path: List(String),\n    run: Runner(a),\n    flags: List(#(String, Flag)),\n    description: String,\n  )\n}\n DEPRECATED: use `glint.cmd` and related builder functions instead to create a Command\n \n Create command stubs to be used in `add_command_from_stub`\n\nStub(\n  path: List(String),\n  run: Runner(a),\n  flags: List(#(String, Flag)),\n  description: String,\n)\n\n\nSynonyms:\nglint.Stub\nglint Stub","url":"glint.html#Stub"},{"doc":"glint","title":"default_config","content":"pub const default_config: Config(a) = Config(pretty_help: None)\n Default config\n\nSynonyms:\nglint.default_config\nglint default_config","url":"glint.html#default_config"},{"doc":"glint","title":"add","content":"pub fn add(to glint: Glint(a), at path: List(String), do contents: Command(\n    a,\n  )) -&gt; Glint(a)\n Adds a new command to be run at the specified path.\n\n If the path is `[]`, the root command is set with the provided function and\n flags.\n\n Note: all command paths are sanitized by stripping whitespace and removing any empty string elements.\n\nSynonyms:\nglint.add\nglint add","url":"glint.html#add"},{"doc":"glint","title":"add_command_from_stub","content":"pub fn add_command_from_stub(to glint: Glint(a), with stub: Stub(\n    a,\n  )) -&gt; Glint(a)\n DEPRECATED: use `glint.cmd` and related builder functions instead to create a Command\n \n Add a command to the root given a stub \n\nSynonyms:\nglint.add_command_from_stub\nglint add_command_from_stub","url":"glint.html#add_command_from_stub"},{"doc":"glint","title":"command","content":"pub fn command(do runner: fn(CommandInput) -&gt; a) -&gt; Command(a)\n\nSynonyms:\nglint.command\nglint command","url":"glint.html#command"},{"doc":"glint","title":"default_pretty_help","content":"pub fn default_pretty_help() -&gt; PrettyHelp\n Default pretty help heading colouring\n mint (r: 182, g: 255, b: 234) colour for usage\n pink (r: 255, g: 175, b: 243) colour for flags\n buttercup (r: 252, g: 226, b: 174) colour for subcommands\n\nSynonyms:\nglint.default_pretty_help\nglint default_pretty_help","url":"glint.html#default_pretty_help"},{"doc":"glint","title":"description","content":"pub fn description(cmd: Command(a), description: String) -&gt; Command(\n  a,\n)\n\nSynonyms:\nglint.description\nglint description","url":"glint.html#description"},{"doc":"glint","title":"execute","content":"pub fn execute(glint: Glint(a), args: List(String)) -&gt; Result(\n  Out(a),\n  Snag,\n)\n Determines which command to run and executes it.\n\n Sets any provided flags if necessary.\n\n Each value prefixed with `--` is parsed as a flag.\n\n This function does not print its output and is mainly intended for use within `glint` itself.\n If you would like to print or handle the output of a command please see the `run_and_handle` function.\n\nSynonyms:\nglint.execute\nglint execute","url":"glint.html#execute"},{"doc":"glint","title":"flag","content":"pub fn flag(cmd: Command(a), at key: String, of flag: Flag) -&gt; Command(\n  a,\n)\n\nSynonyms:\nglint.flag\nglint flag","url":"glint.html#flag"},{"doc":"glint","title":"flags","content":"pub fn flags(cmd: Command(a), with flags: List(#(String, Flag))) -&gt; Command(\n  a,\n)\n\nSynonyms:\nglint.flags\nglint flags","url":"glint.html#flags"},{"doc":"glint","title":"help_flag","content":"pub fn help_flag() -&gt; String\n Function to create the help flag string\n Exported for testing purposes only\n\nSynonyms:\nglint.help_flag\nglint help_flag","url":"glint.html#help_flag"},{"doc":"glint","title":"new","content":"pub fn new() -&gt; Glint(a)\n Creates a new command tree.\n\nSynonyms:\nglint.new\nglint new","url":"glint.html#new"},{"doc":"glint","title":"run","content":"pub fn run(from glint: Glint(a), for args: List(String)) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function ignores any value returned by the command that was run.\n If you would like to do something with the command output please see the run_and_handle function.\n\nSynonyms:\nglint.run\nglint run","url":"glint.html#run"},{"doc":"glint","title":"run_and_handle","content":"pub fn run_and_handle(from glint: Glint(a), for args: List(String), with handle: fn(\n    a,\n  ) -&gt; b) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function calls the provided handler with the value returned by the command that was run.\n\nSynonyms:\nglint.run_and_handle\nglint run_and_handle","url":"glint.html#run_and_handle"},{"doc":"glint","title":"with_config","content":"pub fn with_config(glint: Glint(a), config: Config(a)) -&gt; Glint(a)\n Add the provided config to the existing command tree\n\nSynonyms:\nglint.with_config\nglint with_config","url":"glint.html#with_config"},{"doc":"glint","title":"with_global_flag","content":"pub fn with_global_flag(glint: Glint(a), at key: String, of flag: Flag) -&gt; Glint(\n  a,\n)\n Add global flags to the existing command tree\nSynonyms:\nglint.with_global_flag\nglint with_global_flag","url":"glint.html#with_global_flag"},{"doc":"glint","title":"with_global_flags","content":"pub fn with_global_flags(glint: Glint(a), flags: List(\n    #(String, Flag),\n  )) -&gt; Glint(a)\n Add global flags to the existing command tree\nSynonyms:\nglint.with_global_flags\nglint with_global_flags","url":"glint.html#with_global_flags"},{"doc":"glint","title":"with_pretty_help","content":"pub fn with_pretty_help(glint: Glint(a), pretty: PrettyHelp) -&gt; Glint(\n  a,\n)\n Enable custom colours for help text headers\n For a pre-made colouring use `default_pretty_help()`\n \nSynonyms:\nglint.with_pretty_help\nglint with_pretty_help","url":"glint.html#with_pretty_help"},{"doc":"glint","title":"without_pretty_help","content":"pub fn without_pretty_help(glint: Glint(a)) -&gt; Glint(a)\n Disable custom colours for help text headers\n \nSynonyms:\nglint.without_pretty_help\nglint without_pretty_help","url":"glint.html#without_pretty_help"},{"doc":"glint","title":"glint","content":"","url":"glint.html"}]);